==================================
ninst: NiftyPET Installation Tools
==================================

|Docs| |PyPI-Status|

``ninst`` is a stand-alone Python sub-package of NiftyPET_, dedicated to helping with installation of other sub-packages. Although it is an essential part of NiftyPET_ packaging, ``ninst`` could be used in other projects.

.. _NiftyPET: https://github.com/NiftyPET/NiftyPET

**Documentation with installation manual and tutorials**: https://niftypet.readthedocs.io/

Licence
~~~~~~~

|Licence|

Copyright 2018-20

- `Casper O. da Costa-Luis <https://github.com/casperdcl>`__ @ King's College London
- `Pawel J. Markiewicz <https://github.com/pjmark>`__ @ University College London
- `Contributors <https://github.com/NiftyPET/ninst/graphs/contributors>`__

.. |Docs| image:: https://readthedocs.org/projects/niftypet/badge/?version=latest
   :target: https://niftypet.readthedocs.io/en/latest/?badge=latest
.. |Licence| image:: https://img.shields.io/pypi/l/ninst.svg?label=licence
   :target: https://github.com/NiftyPET/ninst/blob/master/LICENCE
.. |PyPI-Downloads| image:: https://img.shields.io/pypi/dm/ninst.svg?label=PyPI%20downloads
   :target: https://pypi.org/project/ninst
.. |PyPI-Status| image:: https://img.shields.io/pypi/v/ninst.svg?label=latest
   :target: https://pypi.org/project/ninst
